#define DBHOST "localhost"
#define DBUSER "radiusd"
#define DBPASS "changeme"
#define DBBASE "accounting"

#define SELECT_PASSWD "SELECT passwd FROM users WHERE login='%s' AND status='Active'"

#define ACCT_IN "INSERT INTO login (login, start_record) VALUES ('%s',SYSDATE())"
#define ACCT_OUT "INSERT INTO logout (login, duration, ip_address, input_packets, output_packets, end_record) VALUES ('%s',%s,'%s',%s,%s,SYSDATE())"
#define STOP 1
#define START 0
